Enum prs_lib::crypto::Proto [−][src]
#[non_exhaustive]
pub enum Proto {
Gpg,
}Expand description
Crypto protocol.
This list contains all protocols supported by the prs project. This does not mean that all protocols are supported at runtime in a given build.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
GPG crypto.
Implementations