Module prs_lib::crypto::store[][src]

Helpers to use recipients with password store.

Enums

Store crypto error.

Missing key import results.

Traits

Recipients extension for store functionality.

Functions

Import keys from store that are missing in the keychain.

Get the GPG IDs file for a store.

Load the keys for the given store.

Load the recipients for the given store.

Get the public keys directory for a store.

Read GPG fingerprints from store.

Save the keys for the given store.

Save the keys for the given store.

Sync public key files in store with selected recipients.

Write GPG fingerprints to a store.