Struct prs_lib::crypto::ContextPool [−][src]
pub struct ContextPool { /* fields omitted */ }A pool of proto contexts.
Makes using multiple contexts easy, by caching contexts by protocol type and initializing them on demand.
Implementations
impl ContextPool[src]
pub fn empty() -> Self[src]
Create new empty pool.
pub fn get_mut<'a>(&'a mut self, proto: Proto) -> Result<&'a mut Context>[src]
Get mutable context for given proto.
This will initialize the context if no context is loaded for the given proto yet. This may error..