pub fn can_decrypt(store: &Store) -> boolExpand description
Check whether we can decrypt the first secret in the store.
If decryption fails, and this returns false, it means we don’t own any compatible secret key.
Returns true if there is no secret.