Struct prs_lib::store::Secret [−][src]
A password store secret.
Fields
name: StringDisplay name of the secret, relative path to the password store root.
path: PathBufFull path to the password store secret.
Implementations
Construct secret at given full path from given store.
Construct secret at given path in the given password store root.
Get relative path to this secret, root must be given.
Returns pointed to secret.
If this secret is an alias, this will return the pointed to secret. If this secret is not an alias, an error will be returned.
The pointed to secret may be an alias as well.