Struct prs_lib::store::Store [−][src]
pub struct Store {
pub root: PathBuf,
}Expand description
Represents a password store.
Fields
root: PathBufRoot directory of the password store.
This path is always absolute.
Implementations
Get the recipient keys for this store.
Get a tomb helper for this store.
pub fn secret_iter(&self) -> SecretIterⓘNotable traits for SecretIter
impl Iterator for SecretIter type Item = Secret;
pub fn secret_iter(&self) -> SecretIterⓘNotable traits for SecretIter
impl Iterator for SecretIter type Item = Secret;Create secret iterator for this store.
pub fn secret_iter_config(&self, config: SecretIterConfig) -> SecretIterⓘNotable traits for SecretIter
impl Iterator for SecretIter type Item = Secret;
pub fn secret_iter_config(&self, config: SecretIterConfig) -> SecretIterⓘNotable traits for SecretIter
impl Iterator for SecretIter type Item = Secret;Create secret iterator for this store with custom configuration.
Try to find matching secrets for given query.
If secret is found at exact query path, FindSecret::Found is returned.
Otherwise any number of closely matching secrets is returned as FindSecret::Many.
Normalizes a path for a secret in this store.
- Ensures path is within store.
- If directory is given, name hint is appended.
- Sets correct extension.
- Creates parent directories if non existant (optional).