Struct prs_lib::sync::Sync [−][src]
pub struct Sync<'a> { /* fields omitted */ }Sync helper for given store.
Implementations
impl<'a> Sync<'a>[src]
impl<'a> Sync<'a>[src]pub fn new(store: &'a Store) -> Sync<'a>[src]
Construct new sync helper for given store.
pub fn readyness(&self) -> Result<Readyness>[src]
Check readyness of store for syncing.
This checks whether the repository state is clean, which means that there’s no active
merge/rebase/etc.
The repository might be dirty, use sync_is_dirty to check that.
pub fn prepare(&self) -> Result<()>[src]
Prepare the store for new changes.
- If sync is not initialized, it does nothing.
- If sync remote is set, it pulls changes.
pub fn finalize<M: AsRef<str>>(&self, msg: M) -> Result<()>[src]
Finalize the store with new changes.
- If sync is not initialized, it does nothing.
- If sync is initialized, it commits changes.
- If sync remote is set, it pushes changes.
pub fn init(&self) -> Result<()>[src]
Initialize sync.
pub fn clone(&self, url: &str, quiet: bool) -> Result<()>[src]
Clone sync from a remote URL.
pub fn is_init(&self) -> bool[src]
Check whether sync has been initialized in this store.
pub fn remotes(&self) -> Result<Vec<String>>[src]
Get a list of sync remotes.
pub fn remote_url(&self, remote: &str) -> Result<String>[src]
Get the URL of the given remote.
pub fn add_remote_url(&self, remote: &str, url: &str) -> Result<()>[src]
Add the URL of the given remote.
pub fn set_remote_url(&self, remote: &str, url: &str) -> Result<()>[src]
Set the URL of the given remote.
pub fn has_remote(&self) -> Result<bool>[src]
Check whether this store has a remote configured.