pub struct Tomb<'a> {
pub settings: TombSettings,
/* private fields */
}Expand description
Tomb helper for given store.
Fields
settings: TombSettingsTomb settings.
Implementations
Sourceimpl<'a> Tomb<'a>
impl<'a> Tomb<'a>
Sourcepub fn new(
store: &'a Store,
quiet: bool,
verbose: bool,
force: bool,
) -> Tomb<'a>
pub fn new( store: &'a Store, quiet: bool, verbose: bool, force: bool, ) -> Tomb<'a>
Construct new Tomb helper for given store.
Sourcepub fn find_tomb_path(&self) -> Result<PathBuf>
pub fn find_tomb_path(&self) -> Result<PathBuf>
Find the tomb path.
Errors if it cannot be found.
Sourcepub fn find_tomb_key_path(&self) -> Result<PathBuf>
pub fn find_tomb_key_path(&self) -> Result<PathBuf>
Find the tomb key path.
Errors if it cannot be found.
Sourcepub fn open(&self) -> Result<Vec<Err>>
pub fn open(&self) -> Result<Vec<Err>>
Open the tomb.
This will keep the tomb open until it is manually closed. See start_timer().
On success this may return a list with soft-fail errors.
Sourcepub fn resize(&self, mbs: u32) -> Result<()>
pub fn resize(&self, mbs: u32) -> Result<()>
Resize the tomb.
The Tomb must not be mounted and the size must be larger than the current.
Sourcepub fn prepare(&self) -> Result<()>
pub fn prepare(&self) -> Result<()>
Prepare a Tomb store for usage.
- If this store is a Tomb, the tomb is opened.
Sourcepub fn start_timer(&self, sec: u32, force: bool) -> Result<()>
pub fn start_timer(&self, sec: u32, force: bool) -> Result<()>
Set up a timer to automatically close password store tomb.
TODO: add support for non-systemd systems
Sourcepub fn stop_timer(&self) -> Result<()>
pub fn stop_timer(&self) -> Result<()>
Stop automatic close timer if any is running.
Sourcepub fn init(&self, key: &Key, mbs: u32) -> Result<()>
pub fn init(&self, key: &Key, mbs: u32) -> Result<()>
Initialize tomb.
mbs is the size in megabytes.
The given GPG key is used to encrypt the Tomb key with.
Panics
Panics if given key is not a GPG key.
Sourcepub fn is_tomb(&self) -> bool
pub fn is_tomb(&self) -> bool
Check whether the password store is a tomb.
This guesses based on existence of some files. If this returns false you may assume this password store doesn’t use a tomb.
Sourcepub fn is_open(&self) -> Result<bool>
pub fn is_open(&self) -> Result<bool>
Check whether the password store is currently opened.
This guesses based on mount information for the password store directory.
Sourcepub fn fetch_size_stats(&self) -> Result<TombSize>
pub fn fetch_size_stats(&self) -> Result<TombSize>
Fetch Tomb size statistics.
This attempts to gather password store and tomb size statistics, whether this store is a tomb or not.
This is expensive.