Struct prs_lib::tomb::TombSize [−][src]
Holds information for password store Tomb sizes.
Fields
store: Option<u64>Store directory.
tomb_file: Option<u64>Tomb file size.
Implementations
Get Tomb file size in MBs.
Get the desired Tomb size in megabytes based on the current state.
Currently twice the password store size, defaults to minimum of 10.
Determine whether the password store should be resized.