Struct prs_lib::types::Plaintext[][src]

pub struct Plaintext(_);
Plaintext.

Wraps plaintext bytes. This type is limited on purpose, to prevent accidentally leaking the plaintext. Security properties are enforced by secstr::SecVec.

Implementations

New empty plaintext.

Get unsecure reference to inner data.

Warning

Unsecure because we cannot guarantee that the referenced data isn’t cloned. Use with care!

The reference itself is safe to use and share. Data may be cloned from this reference though, when that happens we lose track of it and are unable to securely handle it in memory. You should clone Plaintext instead.

Get the plaintext as UTF8 string.

Warning

Unsecure because we cannot guarantee that the referenced data isn’t cloned. Use with care!

The reference itself is safe to use and share. Data may be cloned from this reference though, when that happens we lose track of it and are unable to securely handle it in memory. You should clone Plaintext instead.

Get the first line of this secret as plaintext.

Returns empty plaintext if there are no lines.

Get all lines execpt the first one.

Returns empty plaintext if there are no lines.

Get line with the given property.

Returns line with the given property. The property prefix is removed, and only the trimmed value is returned. Returns an error if the property does not exist.

This will never return the first line being the password.

Append other plaintext.

Optionally adds platform newline.

Check whether this plaintext is empty.

  • Empty if 0 bytes
  • Empty if bytes parsed as UTF-8 has trimmed length of 0 characters (ignored on encoding failure)