Module prs_lib::crypto [−][src]
Crypto interface.
This module provides an interface to all cryptography features that are used in prs.
It supports multiple cryptography protocols (e.g. GPG) and multiple backends (e.g. GPGME, GnuPG). The list of supported protocols and backends may be extended in the future.
Modules
Crypto backends.
Prelude for common crypto traits.
Crypto protocols.
Provides interface for crypto recipients.
Helpers to use recipients with password store.
Common crypto utilities.
Structs
Enums
Constants
Default proto.
Traits
Defines generic crypto context.
Functions
Get crypto context for given proto type at runtime.