Enum prs_lib::crypto::Proto [−][src]
#[non_exhaustive]
pub enum Proto {
Gpg,
}Crypto protocol.
This list contains all protocols supported by the prs project. This does not mean that all protocols are supported at runtime in a given build.
Variants (Non-exhaustive)
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
GPG crypto.
Implementations
impl Proto[src]