Struct prs_lib::store::Secret[][src]

pub struct Secret {
    pub name: String,
    pub path: PathBuf,
}

A password store secret.

Fields

name: String

Display name of the secret, relative path to the password store root.

path: PathBuf

Full path to the password store secret.

Implementations

impl Secret[src]

pub fn from(store: &Store, path: PathBuf) -> Self[src]

Construct secret at given full path from given store.

pub fn in_root(root: &Path, path: PathBuf) -> Self[src]

Construct secret at given path in the given password store root.

pub fn relative_path<'a>(
    &'a self,
    root: &'a Path
) -> Result<&'a Path, StripPrefixError>
[src]

Get relative path to this secret, root must be given.

pub fn alias_target(&self, store: &Store) -> Result<Secret>[src]

Returns pointed to secret.

If this secret is an alias, this will return the pointed to secret. If this secret is not an alias, an error will be returned.

The pointed to secret may be an alias as well.