Struct prs_lib::store::SecretIter [−][src]
pub struct SecretIter { /* fields omitted */ }Iterator that walks through password store secrets.
This walks all password store directories, and yields password secrets. Hidden files or directories are skipped.
Implementations
impl SecretIter[src]
impl SecretIter[src]pub fn new(root: PathBuf, config: SecretIterConfig) -> Self[src]
Create new store secret iterator at given store root.
pub fn filter_name(self, filter: Option<String>) -> FilterSecretIter<Self>ⓘNotable traits for FilterSecretIter<I>
impl<I> Iterator for FilterSecretIter<I> where
I: Iterator<Item = Secret>, type Item = Secret;[src]
Notable traits for FilterSecretIter<I>
impl<I> Iterator for FilterSecretIter<I> where
I: Iterator<Item = Secret>, type Item = Secret;Transform into a filtered secret iterator.