Struct prs_lib::store::Store [−][src]
pub struct Store {
pub root: PathBuf,
}Represents a password store.
Fields
root: PathBufRoot directory of the password store.
This path is always absolute.
Implementations
impl Store[src]
impl Store[src]pub fn open<P: AsRef<str>>(root: P) -> Result<Self>[src]
Open a store at the given path.
pub fn recipients(&self) -> Result<Recipients>[src]
Get the recipient keys for this store.
pub fn sync(&self) -> Sync<'_>[src]
Get a sync helper for this store.
pub fn secret_iter(&self) -> SecretIterⓘNotable traits for SecretIter
impl Iterator for SecretIter type Item = Secret;[src]
Notable traits for SecretIter
impl Iterator for SecretIter type Item = Secret;Create secret iterator for this store.
pub fn secret_iter_config(&self, config: SecretIterConfig) -> SecretIterⓘNotable traits for SecretIter
impl Iterator for SecretIter type Item = Secret;[src]
Notable traits for SecretIter
impl Iterator for SecretIter type Item = Secret;Create secret iterator for this store with custom configuration.
pub fn secrets(&self, filter: Option<String>) -> Vec<Secret>[src]
List store password secrets.
pub fn find_at(&self, path: &str) -> Option<Secret>[src]
Try to find matching secret at path.
pub fn find(&self, query: Option<String>) -> FindSecret[src]
Try to find matching secrets for given query.
If secret is found at exact query path, FindSecret::Found is returned.
Otherwise any number of closely matching secrets is returned as FindSecret::Many.
pub fn normalize_secret_path<P: AsRef<Path>>(
&self,
target: P,
name_hint: Option<&str>,
create_dirs: bool
) -> Result<PathBuf>[src]
&self,
target: P,
name_hint: Option<&str>,
create_dirs: bool
) -> Result<PathBuf>
Normalizes a path for a secret in this store.
- Ensures path is within store.
- If directory is given, name hint is appended.
- Sets correct extension.
- Creates parent directories if non existant (optional).